from __future__ import unicode_literals

from math import floor

from django import template
from django.contrib.messages import constants as message_constants
from django.template import Context
from django.utils import six
from django.utils.safestring import mark_safe

register = template.Library()


@register.inclusion_tag("django_2gis_maps/map/map.html")
def render_map(instance, **kwargs):
    context = {
        'instance': instance,
        'geolocation': instance.get_location,
    }
    # return
    if kwargs:
        context.update(kwargs)
    return context



class DoubleGisMixin(object):
    """Mixin to another class to provide access to a User's ``Score``."""

    @property
    def get_location(self):
        if self.geolocation:
            result = []
            if ';' in str(self.geolocation):
                for i in str(self.geolocation).split(';'):
                    result.append({'lat': i.split(',')[0], 'lng': i.split(',')[1]})
                return result
            result.append({'lat': str(self.geolocation).split(',')[0], 'lng': str(self.geolocation).split(',')[1]})
            return result



from django.contrib import admin
from django.forms import TextInput

from django_2gis_maps.fields import AddressField, GeoLocationField
from django_2gis_maps.widgets import *


class DoubleGisAdmin(admin.ModelAdmin):
    formfield_overrides = {
        AddressField: {
            'widget': DoubleGisMapsAddressWidget
        },
        GeoLocationField: {
            'widget': TextInput(attrs={
                'readonly': 'readonly'
            })
        },
    }

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        try:
            multiple_markers = self.multiple_markers
        except:
            multiple_markers = False
        if multiple_markers:
            self.formfield_overrides[AddressField]['widget'] = DoubleGisMapsMultipleMarkersWidget



from django.conf import settings
from django.forms import widgets


class DoubleGisMapsAddressWidget(widgets.TextInput):
    """a widget that will place a google map right after the #id_address field"""
    template_name = "django_2gis_maps/widgets/map_widget.html"

    class Media:
        css = {
            'all': (settings.STATIC_URL +
                    'django_2gis_maps/css/adminMap.css',)
        }
        js = (
            'http://code.jquery.com/jquery-latest.min.js',
            'https://maps.api.2gis.ru/2.0/loader.js?pkg=full&skin=dark',
            settings.STATIC_URL + 'django_2gis_maps/js/addMarkers.js',
            settings.STATIC_URL + 'django_2gis_maps/js/adminMap.js',
        )


class DoubleGisMapsMultipleMarkersWidget(widgets.TextInput):
    template_name = "django_2gis_maps/widgets/multiple_markers_widget.html"

    class Media:
        css = {
            'all': (settings.STATIC_URL +
                    'django_2gis_maps/css/adminMapMultipleMarkers.css',)
        }
        js = (
            'http://code.jquery.com/jquery-latest.min.js',
            'https://maps.api.2gis.ru/2.0/loader.js?pkg=full&skin=dark',
            settings.STATIC_URL + 'django_2gis_maps/js/addMarkers.js',
            settings.STATIC_URL + 'django_2gis_maps/js/adminMapMultipleMarkers.js',
        )



import os
from setuptools import setup

# README = os.path.join(os.path.dirname(__file__), 'README.md')
# LONG_DESCRIPTION = open(README, 'r').read()
CLASSIFIERS = [
    "Development Status :: 4 - Beta",
    "Environment :: Web Environment",
    "Framework :: Django",
    "Framework :: Django",
    "Framework :: Django :: 1.11",
    "Framework :: Django :: 2.0",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: BSD License",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3.4",
    "Programming Language :: Python :: 3.5",
    "Programming Language :: Python :: 3.6",
    "Topic :: Software Development",
    "Topic :: Software Development :: Libraries :: Application Frameworks",
]

setup(
    name="django_2gis_maps",
    version='1.0.2',
    author="Noors Ergesh",
    author_email="jackmovies01@gmail.com",
    description="Plugs 2gis maps for Django admin",
    # long_description=LONG_DESCRIPTION,
    url="https://github.com/NursErgesh/django_2gis_maps.git",
    packages=("django_2gis_maps",),
    include_package_data=True,
    install_requires=open('requirements/requirements.txt').read().splitlines(),
    tests_require=open('requirements/test.txt').read().splitlines(),
    classifiers=CLASSIFIERS,
    zip_safe=False,
)
